<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Storage;use App\Exhibition;
use App\Exhibition_image;

class ExhibitionsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $exhibitions = Exhibition::all();
        return view('Backend.Exhibitions.list')->with('exhibitions',$exhibitions);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('Backend.Exhibitions.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules =['title' => 'required', 'description' => 'required','images' => 'required|max:20480', 'thumbnail' => 'required'];

        $validation = $this->Validate($request,$rules);

        $exhibition = new Exhibition;
        $exhibition->title       = $request->title;
        $exhibition->description = $request->description;
        $exhibition->type        = $request->type;

        if($exhibition->save())
        {
            if($request->hasFile('thumbnail'))
            {
                // Save Press and Exhibitions thumbnail Image
                $exhibition_image = new Exhibition_image;
                $image            = $request->file('thumbnail');
                $filename         = 'thumbnail_'.rand(1000,3000).'_'.time().'.'. $image->getClientOriginalExtension();
                $destination_path = 'public/Exhibition-Images';
                $image->storeAs($destination_path,$filename);
                $exhibition_image->exhibition_id = $exhibition->id;
                $exhibition_image->image = $filename;
                $exhibition_image->type  = 'thumbnail';
                $exhibition_image->save();
            }

            if($request->hasFile('images'))
            {
                // Save Press and Exhibition Images multipal
                foreach ($request->images as $key => $value) 
                {
                    $exhibition_image = new Exhibition_image;
                    $image            = $value;
                    $filename         = 'normal_'.rand(1000,3000).'_'.time().'.'. $image->getClientOriginalExtension();
                    $destination_path = 'public/Exhibition-Images';
                    $image->storeAs($destination_path,$filename);
                    $exhibition_image->exhibition_id = $exhibition->id;
                    $exhibition_image->image = $filename;
                    $exhibition_image->type  = 'normal_image';
                    $exhibition_image->save();
                }
            }
            return redirect('exhibition')->with('alert-success', 'Press or Exhibition Created Successfully');
        }
        else
        {
            return redirect('exhibition/create')->with('alert-error', $validation->errors());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $exhibition = Exhibition::find($id);
        return view('Backend.Exhibitions.show')->with('exhibition',$exhibition);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $exhibition = Exhibition::find($id);
        return view('Backend.Exhibitions.edit')->with('exhibition',$exhibition);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules =['title' => 'required', 'description' => 'required','images' => 'required|max:20480', 'thumbnail' => 'required'];

        $validation = $this->Validate($request,$rules);
        $exhibition = Exhibition::find($id);
        if($exhibition)
        {
            $exhibition->title       = $request->title;
            $exhibition->description = $request->description;
            $exhibition->type        = $request->type;

            if($exhibition->update())
            {
                if($request->hasFile('thumbnail'))
                {
                    $exhibition = Exhibition::find($id);
                    if($exhibition->exhibition_images)
                    {
                        foreach ($exhibition->exhibition_images as $key => $value) 
                        {
                            if($value->type == 'thumbnail')
                            {
                                $value->delete();
                            }
                        }
                    }
                    //Save Press and Exhibition thumbnail Image
                    $exhibition_image = new Exhibition_image;
                    $image            = $request->thumbnail;
                    $filename         = 'thumbnail_'.rand(1000,3000).'_'.time().'.'. $image->getClientOriginalExtension();
                    $destination_path = 'public/Exhibition-Images';
                    $image->storeAs($destination_path,$filename);
                    $exhibition_image->exhibition_id = $exhibition->id;
                    $exhibition_image->image = $filename;
                    $exhibition_image->type  = 'thumbnail';
                    $exhibition_image->save();
                }

                if($request->hasFile('images'))
                {
                    $exhibition = Exhibition::find($id);
                    if($exhibition->exhibition_images)
                    {
                        foreach ($exhibition->exhibition_images as $key => $value) 
                        {
                            if($value->type == 'normal_image')
                            {
                                $value->delete();
                            }
                        }
                    }
                    //Save Press and Exhibition Images multipal
                    foreach ($request->images as $key => $image) 
                    {
                        $exhibition_image = new Exhibition_image;
                        $image            = $image;
                        $filename         = 'normal_'.rand(1000,3000).'_'.time().'.'. $image->getClientOriginalExtension();
                        $destination_path = 'public/Exhibition-Images';
                        $image->storeAs($destination_path,$filename);
                        $exhibition_image->exhibition_id = $exhibition->id;
                        $exhibition_image->image = $filename;
                        $exhibition_image->type  = 'normal_image';
                        $exhibition_image->save();
                    }
                    return redirect('exhibition')->with('alert-success', 'Press or Exhibition Updated Successfully');
                }

                return redirect('exhibition')->with('alert-success', 'Press or Exhibition Updated Successfully');
            }
        }
        else
        {
            return redirect('exhibition')->with('alert-error', 'Press or Exhibition can not find');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $exhibition = Exhibition::find($id);
        if($exhibition->exhibition_images)
        {
            foreach ($exhibition->exhibition_images as $key => $value) 
            {
                    $value->delete();
            }
        }
        if($exhibition->delete())
        {    
            return redirect('exhibition')->with('alert-error', 'Press or Exhibition Deleted Successfully');
        }
    }

    public function get_exhibitions()
    {
        $exhibitions_images = [];
        $press_images = [];
        $exhibitions = Exhibition::where('type','=','exhibition')->get();
        $press       = Exhibition::where('type','=','press')->get();
        foreach ($exhibitions as $key => $exhibition) {
            $exhibitions_images[$key] = $exhibition->exhibition_images;
        }
        foreach ($press as $key => $item) {
            $press_images[$key] = $item->exhibition_images;
        }
        $pagetitle   = 'Press & Exhibitions';
        return view('Frontend.press-exhibitions')->with('pagetitle',$pagetitle)
                ->with('exhibitions',$exhibitions)->with('press',$press)->with('exhibitions_images',$exhibitions_images)
                ->with('press_images',$press_images);
    }
}
