@extends('layouts.app')
@section('pagetitle', 'Product')
@section('subtitle', 'Create New')
@section('page_css')
<link href="{{url('assets/select2/css/select2.min.css')}}" rel="stylesheet" type="text/css"/>
<link href="{{url('assets/summernote/dist/summernote.css')}}" rel="stylesheet" type="text/css"/>
@endsection
@section('content')
        <div class="row">
            <div class="col-lg-12">
                <!--breadcrumbs start -->
                <ul class="breadcrumb">
                    <li><a href="{{ url('/') }}"><i class="fa fa-home"></i> Home</a></li>
                    <li><a href="{{ redirect()->back()->getTargetUrl() }}">@yield('pagetitle')</a></li>
                    <li class="active"><strong>@yield('subtitle')</strong></li>
                </ul>
                <!--breadcrumbs end -->
            </div>
        </div>
        <div class="row">
                <div class="col-lg-12">
                    <section class="panel">
                        <header class="panel-heading">
                            @yield('pagetitle') <small> Main Section</small>
                        </header>
                        <div class="panel-body">
                            <form method="post" action="{{ url('product/store') }}" class="form-horizontal tasi-form" enctype="multipart/form-data">
                                {{ csrf_field() }}
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Category</label>
                                    <div class="col-sm-10">
                                        <select class="js-example-basic-single form-control" name="category" id="category" required>
                                            <option></option>
                                            @foreach ($categories as $category)
                                            <option value="{{$category->id}}">{{$category->title}}</option>
                                            @endforeach
                                        </select>
                                        <small class="text-danger">{{ $errors->first('category') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Sub Category</label>
                                    <div class="col-sm-10">
                                        <select class="js-example-basic-single form-control" name="sub_category" id="sub_category" required>
                                            <option></option>
                                        </select>
                                        <small class="text-danger">If Selected category no subcategory then first create a subcategory</small><br>
                                        <small class="text-danger">{{ $errors->first('sub_category') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Status</label>
                                    <div class="col-sm-10">
                                        <select class="js-example-basic-single form-control" name="status" id="status" required>
                                            <option></option>
                                            <option value="reserved">Reserved</option>
                                            <option value="sold">Sold</option>
                                            <option value="open">Open</option>
                                            <option value="archive">Archive</option>
                                        </select>
                                        <small class="text-danger">{{ $errors->first('status') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Title</label>
                                    <div class="col-sm-10">
                                        <input type="text" class="form-control" name="title" id="title" value="{{ old('title')}}" onkeyup="generate_slug(this)">
                                        <small class="text-danger">{{ $errors->first('title') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Slug</label>
                                    <div class="col-sm-10">
                                        <input type="text" class="form-control" name="slug" id="slug" value="{{ old('slug')}}">
                                        <small class="text-danger">{{ $errors->first('slug') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Unique Id</label>
                                    <div class="col-sm-10">
                                        <input type="text" class="form-control" name="unique_id" id="unique_id" value="{{ old('unique_id')}}">
                                        <small class="text-danger">{{ $errors->first('unique_id') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Short Description</label>
                                    <div class="col-sm-10">
                                        <textarea class="summernote form-control" name="short_description" id="short_description" value="{{ old('short_description')}}"></textarea>
                                        <small class="text-danger">{{ $errors->first('short_description') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Thumbnail Image</label>
                                    <div class="col-sm-10">
                                        <input type="file" class="form-control" name="thumbnail" id="thumbnail"  value="{{ old('thumbnail')}}">
                                        <small class="text-danger">Select Product Thumbnail Image single Image Note: (If select Hero Image then Thumbnail image do not select).</small>
                                        <small class="text-danger">{{ $errors->first('thumbnail') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Hero Image</label>
                                    <div class="col-sm-10">
                                        <input type="file" class="form-control" name="hero_image" id="hero_image"  value="{{ old('hero_image')}}">
                                        <small class="text-danger">Select Product Hero Image single Image Note: (If select Thumbnail Image then hero image do not select).</small>
                                        <small class="text-danger">{{ $errors->first('hero_image') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Main Image</label>
                                    <div class="col-sm-10">
                                        <input type="file" class="form-control" name="main_image" id="main_image"  value="{{ old('main_image')}}" >
                                        <small class="text-danger">Select Product Main Image single Image</small>
                                        <small class="text-danger">{{ $errors->first('main_image') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Country</label>
                                    <div class="col-sm-10">
                                        <input type="text" class="form-control" name="country" id="country" value="{{ old('country')}}">
                                        <small class="text-danger">{{ $errors->first('country') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Date</label>
                                    <div class="col-sm-10">
                                        <input type="text" class="form-control" name="date" id="date" value="{{ old('date')}}">
                                        <small class="text-danger">{{ $errors->first('date') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Gallery Images</label>
                                    <div class="col-sm-10">
                                        <input type="file" class="form-control" name="images[]" id="images"  value="{{ old('images')}}" multiple>
                                        <small class="text-danger">Select Product Gallery Images Multiple Images</small>
                                        <small class="text-danger">{{ $errors->first('images') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Product Description</label>
                                    <div class="col-md-10">
                                        <textarea class="summernote form-control" name="description" id="description" value="{{ old('description')}}"></textarea>
                                        <small class="text-danger">{{ $errors->first('description') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Second Description</label>
                                    <div class="col-md-10">
                                        <textarea class="summernote form-control" name="second_description" id="second_description" value="{{ old('second_description')}}"></textarea>
                                        <small class="text-danger">{{ $errors->first('second_description') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Meta Title</label>
                                    <div class="col-sm-10">
                                        <input type="text" class="form-control" name="meta_title" id="meta_title" value="{{ old('meta_title')}}">
                                        <small class="text-danger">{{ $errors->first('meta_title') }}</small>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 col-sm-2 control-label">Meta Description</label>
                                    <div class="col-md-10">
                                        <textarea class="summernote form-control" name="meta_description" id="meta_description" value="{{ old('meta_description')}}"></textarea>
                                        <small class="text-danger">{{ $errors->first('meta_description') }}</small>
                                    </div>
                                </div>
                                <button type="submit" class="btn btn-success">Create</button>
                            </form>
                            </div>
                    </section>
                </div>
            </div>
@endsection
@section('page_js')
<script type="text/javascript" src="{{url('assets/select2/js/select2.min.js')}}"></script>
<!--select2-->
<script type="text/javascript">
    $(document).ready(function () {
        $(".js-example-basic-single").select2({
            placeholder: "Please Select..."
        });

        $(".select2_multiple").select2({
            placeholder: "Please Select..."
        });
    });
</script>
<!--summernote-->
<script type="text/javascript" src="{{url('assets/summernote/dist/summernote.min.js')}}"></script>
<script>
    jQuery(document).ready(function(){

        $('.summernote').summernote({
            height: 200,                 // set editor height
	    defaultFontName : "Sans-serif",
            minHeight: null,             // set minimum height of editor
            maxHeight: null,             // set maximum height of editor
            fontNamesIgnoreCheck: ["Sans-serif"],
            fontNames: ["Sans-serif","Roboto","Arial", "Arial Black", "Comic Sans MS", "Courier New",
                             "Helvetica Neue", "Helvetica", "Impact", "Lucida Grande",
                             "Tahoma", "Times New Roman", "Verdana","Gotham-Webfont"],
            focus: true                 // set focus to editable area after initializing summernote
        });
    });
</script>
<script type="text/javascript">
    $(document).ready(function() {

        $(document).on('change','#category' ,function() {
            
            var cat_id=$(this).val();
            var op=" ";
           
            $.ajax({
                type:'get',
                url:'{!!URL::to('product/subcategory') !!}',
                data:{'id':cat_id},
                dataType:'json',
                success:function(data){
                    op+='<option value="" selected="selected"> Select Sub Category </option>';
                    for(var i=0;i<data.length;i++){
                        op+='<option value="'+ data[i].id+'"> '+ data[i].title+' </option>';
                    }
                    $('#sub_category').html(" ");
                    $('#sub_category').append(op);
                    
                },
                error:function(){

                }
            });
        });

    });
    function generate_slug(field){
    	newval = $(field).val(). toLowerCase();
    	newval = replaceAll(newval,' ','-');
    	$('#slug').val(newval)
    }
    function replaceAll(str, find, replace) {
	    return str.replace(new RegExp(find, 'g'), replace);
	}
</script>
@endsection