<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Slider;
use Storage;

class SlidersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $slider_images = Slider::all();
        return view('Backend.Slider.list')->with('slider_images',$slider_images);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('Backend.Slider.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules =['image' => 'required'];

        $validation = $this->Validate($request,$rules);

        $slider = new Slider;
        // Save Slider Image
        if($request->hasFile('image'))
        {
            $image            = $request->file('image');
            $filename         = 'slider_'.rand(51000,55000).'_'.time().'.'. $image->getClientOriginalExtension();
            $destination_path = 'public/Slider-Images';
            $image->storeAs($destination_path,$filename);
            $slider->image = $filename;
            $slider->save();
            return redirect('slider')->with('alert-success', 'Slider Image Created Successfully');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $slider_image = Slider::find($id);
        return view('Backend.Slider.show')->with('slider_image',$slider_image);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $slider_image = Slider::find($id);
        return view('Backend.Slider.edit')->with('slider_image',$slider_image);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules =['image' => 'required'];

        $validation = $this->Validate($request,$rules);

        $slider = Slider::find($id);
        // Save Slider Image
        if($request->hasFile('image'))
        {
            $image            = $request->file('image');
            $filename         = 'slider_'.rand(51000,55000).'_'.time().'.'. $image->getClientOriginalExtension();
            $destination_path = 'public/Slider-Images';
            $image->storeAs($destination_path,$filename);
            $slider->image = $filename;
            $slider->update();
            return redirect('slider')->with('alert-success', 'Slider Image Updated Successfully');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $slider = Slider::find($id);
        if($slider->delete())
        {    
            return redirect('slider')->with('alert-error', 'Slider Image Deleted Successfully');
        }
    }

    public function status($id)
    {
        $slider = Slider::find($id);
        if($slider->status == 1)
        {
            $slider->status = 0;
            $slider->update();
            return redirect('slider')->with('alert-success', 'Slider Image Deactivated Successfully');
        }
        else
        {
            $slider->status = 1;
            $slider->update();
            return redirect('slider')->with('alert-success', 'Slider Image activated Successfully');
        }
    }
}
