<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Storage;use App\Category;

class SubCategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $categories = Category::where('parent','=',0)->get();
        $sub_categories = Category::where('parent','!=',0)->get();
        return view('Backend.Sub_Categories.list')->with('categories',$categories)->with('sub_categories',$sub_categories);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $categories = Category::where('parent','=',0)->get();
        return view('Backend.Sub_Categories.create')->with('categories',$categories);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules =['title' => 'required','parent' => 'required','slug' => 'required'];

        $validation = $this->Validate($request,$rules);

        $slug =Category::where('slug','=',$request->slug)->first();
        if(!$slug)
        {
            $sub_category = new Category;
            $sub_category->title = $request->title;
            $sub_category->slug  = $request->slug;
            $sub_category->description = $request->description;
            $sub_category->parent = $request->parent;

            // Save Category Image
            if($request->hasFile('image'))
            {
                $image            = $request->file('image'); 
                $filename         = time().'.'. $image->getClientOriginalExtension();
                $destination_path = 'public/Sub-Category-Images';
                $image->storeAs($destination_path,$filename);
                $sub_category->image = $filename;
            }

            if($sub_category->save())
            {    
                return redirect('sub_categories')->with('alert-success', 'Sub Category Created Successfully');
            }
            else
            {
                return redirect('sub_categories/create')->with('alert-error', $validation->errors());
            }
        }
        else
        {
            return redirect('sub_categories/create')->with('alert-error','Please select a unique slug This slug already exists');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $sub_category = Category::find($id);
        $category     = Category::find($sub_category->parent);
        return view('Backend.Sub_Categories.show')->with('category',$category)->with('sub_category',$sub_category);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $sub_category = Category::find($id);
        $categories     = Category::where('parent','=',0)->get();
        return view('Backend.Sub_Categories.edit')->with('categories',$categories)->with('sub_category',$sub_category);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules =['title' => 'required','parent' => 'required','slug' => 'required'];

        $validation = $this->Validate($request,$rules);
        $sub_category = Category::find($id);
        if($sub_category)
        {
            $sub_category->title = $request->title;
            $sub_category->slug  = $request->slug;
            $sub_category->description = $request->description;
            $sub_category->parent = $request->parent;

            // Save Category Image
            if($request->hasFile('image'))
            {
                $image            = $request->file('image'); 
                $filename         = time().'.'. $image->getClientOriginalExtension();
                $destination_path = 'public/Sub-Category-Images';
                $image->storeAs($destination_path,$filename);
                $sub_category->image = $filename;
            }

            if($sub_category->update())
            {    
                return redirect('sub_categories')->with('alert-success', 'Sub Category Updated Successfully');
            }
            else
            {
                return redirect('sub_categories/create')->with('alert-error', $validation->errors());
            }
        }
        else
        {
            return redirect('sub_categories')->with('alert-error', 'Sub Category can not find');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $sub_category = Category::find($id);
        if($sub_category->delete())
        {    
            return redirect('sub_categories')->with('alert-error', 'Sub Category Deleted Successfully');
        }
    }
}
