<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Auth,\App\User;
use Illuminate\Support\Facades\Hash;
use Storage;

class UsersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $users = User::all();
        return view('Backend.User.list')->with('users',$users);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('Backend.User.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules= [
            'first_name' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|min:6|confirmed'
        ];

        $validator = $this->Validate($request,$rules);
        $user =User::where('email',$request->email)->first();
        if(!$user)
        {
            $user = new User;
            $user->first_name   =$request->first_name;
            $user->last_name    =$request->last_name;
            $user->email        =$request->email;
            $user->mobile       =$request->mobile;
            $user->type         =$request->type;
            $user->address      =$request->address;
            $user->password     =Hash::make($request->password);

            // Save User Profile Image
            if($request->hasFile('picture'))
            {
                $image            = $request->file('picture'); 
                $filename         = time().'.'. $image->getClientOriginalExtension();
                $destination_path = 'public/User-Images';
                $image->storeAs($destination_path,$filename);
                $user->picture = $filename;
            }

            if($user->save())
            {    
                return redirect('user')->with('alert-success', 'User Created Successfully');
            }
            else
            {
                return redirect('user/create')->with('alert-error', $validator->errors());
            }
        }
        else
        {
            return redirect('user/create')->with('alert-error', 'This Email is Already Exist');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $user = User::find($id);
        return view('Backend.User.show')->with('user',$user);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = User::find($id);
        return view('Backend.User.edit')->with('user',$user);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $user = User::find($id);
        if($user)
        {
            $user->first_name   =$request->first_name;
            $user->last_name    =$request->last_name;
            $user->email        =$request->email;
            $user->mobile       =$request->mobile;
            $user->type         =$request->type;
            $user->address      =$request->address;

            // Save User Profile Image
            if($request->hasFile('picture'))
            {
                $image            = $request->file('picture'); 
                $filename         = time().'.'. $image->getClientOriginalExtension();
                $destination_path = 'public/User-Images';
                $image->storeAs($destination_path,$filename);
                $user->picture = $filename;
            }

            if($user->update())
            {    
                return redirect('user')->with('alert-success', 'User Updated Successfully');
            }
            else
            {
                return redirect('user/create')->with('alert-error', $validator->errors());
            }
        }
        else
        {
            return redirect('user')->with('alert-error', 'User can not find');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user = User::find($id);
        if($user->delete())
        {    
            return redirect('companies')->with('alert-error', 'User Deleted Successfully');
        }
    }
}
